"""zabbixctl - CLI for Zabbix API"""

__version__ = '1.0.2'

import json
import getpass
import sys
from utils import Cache, build_parsers, getlogger
import logging
from Zabbix import Zabbix
from datetime import datetime


def main(args=None):
    logger = getlogger()
    parser = build_parsers(version=__version__)

    if args is None:
        try:
            args = parser.parse_args(sys.argv[1:])
        except IOError as e:
            logger.error("Could not open file %s: %s" %
                         (e.filename, e.strerror))
            exit(1)

    if args.debug:
        logger.setLevel(logging.DEBUG)
        logger.debug("Debug enabled")

    method_type = getattr(args, 'type')
    method = getattr(args, 'subparser_name')

    if method not in ['help']:
        Z = {}
        rets = {}
        for host in args.hosts:
            Z[host] = Zabbix(host, args.noverify, args.cacert,
                             args.http, args.timeout)
            if not Z[host].status:
                if 'Not authorized' in Z[host].error:
                    Z[host].auth(args.user, getpass.getpass())
                else:
                    exit('Error connecting to Zabbix API: {0}'.format(
                        Z[host].error
                    )
                    )

            func = getattr(
                getattr(getattr(Z[host], 'zapi'), method_type), method)
            args_real = Z[host].parse_args(args.arguments)
            if type(args_real) == str or type(args_real) == int:
                rets[host] = func(str(args_real))
            elif type(args_real) == list:
                rets[host] = func(*args_real)
            else:
                rets[host] = func(**args_real)
        final = []
        for ret in rets:
            # if the results are not a list, the final output should be final
            # this was added to support the configuration.export method of the
            # API
            if type(rets[ret]) == list:
                final += rets[ret]
            elif type(rets[ret]) == dict:
                final = rets[ret]
            else:
                final = eval(rets[ret])

        if any(method_type in s for s in ['alert']):
            final = sorted(final, key=lambda k: k['clock'])

        # If there is a timestamp we want to do stuff to it
        if method not in ['create', 'delete', 'update', 'export']:
            # Check if one of the following keys exist
            list_of_checks = ['clock', 'lastchange']
            matched_check = None
            for check in list_of_checks:
                try:
                    if final[0].get(check, None):
                        matched_check = check
                except IndexError:
                    pass
        else:
            matched_check = None

        # If a key exists, then sort on that key and update the unix_timestamp
        # to readable format
        if matched_check:
            final = sorted(final, key=lambda k: k[matched_check])
            for item in final:
                item[matched_check] = str(
                    datetime.fromtimestamp(float(item[matched_check])))
        sys.stdout.write(json.dumps(final, indent=2))
    else:
        logger.info(
            'https://www.zabbix.com/documentation/2.2/manual/api/reference/{0}'.format(method_type))

if __name__ == '__main__':
    main()



from pyzabbix import ZabbixAPI, ZabbixAPIException
import json
import getpass
import sys
import logging
from utils import Cache
from requests.exceptions import HTTPError, ConnectionError
#import urllib3

c = Cache('/tmp/zabbix.cache')


class Zabbix(object):
    status = True
    error = None

    def __init__(self, host, noverify=False, cacert=None, http=False, timeout=30):
        self.logger = logging.getLogger('zabbixctl')
        self.zabbix_url = host
        protocol = 'http' if http else 'https'

        self.zabbix_url = '{0}://{1}/zabbix'.format(protocol, host)

        self.logger.debug(self.zabbix_url)

        self.zapi = ZabbixAPI(self.zabbix_url)

        if cacert is not None:
            self.logger.debug(
                'Setting zapi.session.verify to {0}'.format(cacert))
            self.zapi.session.verify = cacert

        if noverify:
            self.logger.debug('Setting zapi.session.verify to False')
            self.zapi.session.verify = False

        self.zapi.timeout = timeout
        self.fetch_zabbix_api_version()

        self.host = host
        token = c.get(host)
        if token:
            self.logger.debug('Found token for {0}'.format(host))
            self.zapi.auth = token
            # Let's test the token by grabbing the api version
            self.fetch_zabbix_api_version()
        else:
            self.status = False

    def fetch_zabbix_api_version(self):
        try:
            return self.zapi.apiinfo.version()
        except ZabbixAPIException as e:
            self.status = False
            if 'Not authorized' in str(e):
                self.logger.debug('Token not authorized for {0}'.format(host))
                self.error = e
            else:
                self.error = e
        except (HTTPError, ConnectionError) as e:
            self.error = e
        return False

    def status(self):
        return self.status

    def auth(self, username, password):
        try:
            self.zapi.login(username, password)
            self.error = None
            self.status = True
            c.write(self.host, self.zapi.auth)
        except ZabbixAPIException as e:
            self.error = e
            self.status = False
            return False
        return True

    def parse_args(self, args):
        arguments = {}
        if args is not None:
            for argument in args:
                if '=' in argument:
                    tmp = [a for a in argument.split('=', 1)]
                    try:
                        value = eval(tmp[1])
                    except (NameError, SyntaxError):
                        value = tmp[1]
                    arguments[tmp[0]] = value
                else:
                    arguments = eval(argument)
        return arguments

if __name__ == '__main__':
    Z = Zabbix('zabbix.yourdomain.net')
    username = getpass.getuser()
    password = getpass.getpass()
    Z.auth(username, password)
    import pdb
    pdb.set_trace()



from setuptools import setup
from sys import path

from zabbixctl import __version__

path.insert(0, '.')

NAME = "zabbixctl"

if __name__ == "__main__":

    setup(
        name = NAME,
        version = __version__,
        author = "Tony Rogers",
        author_email = "tony.rogers@rackspace.com",
        url = "https://github.com/teriyakichild/zabbixctl",
        license = 'ASLv2',
        packages = [NAME],
        package_dir = {NAME: NAME},
        description = "zabbixctl - Utility that connects to Zabbix API",

        install_requires = ['requests>=2.0.0',
                            'argparse',
                            'pyzabbix',
                            'ConfigParser'],
        entry_points={
            'console_scripts': [ 'zabbixctl = zabbixctl:main' ],
        }
    )

